// Code generated by smithy-go-codegen DO NOT EDIT.

package cloudwatchlogs

import (
	"context"
	"fmt"
	awsmiddleware "github.com/aws/aws-sdk-go-v2/aws/middleware"
	"github.com/aws/aws-sdk-go-v2/service/cloudwatchlogs/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns a list of all CloudWatch Logs account policies in the account.
//
// To use this operation, you must be signed on with the correct permissions
// depending on the type of policy that you are retrieving information for.
//
//   - To see data protection policies, you must have the
//     logs:GetDataProtectionPolicy and logs:DescribeAccountPolicies permissions.
//
//   - To see subscription filter policies, you must have the
//     logs:DescribeSubscriptionFilters and logs:DescribeAccountPolicies permissions.
//
//   - To see transformer policies, you must have the logs:GetTransformer and
//     logs:DescribeAccountPolicies permissions.
//
//   - To see field index policies, you must have the logs:DescribeIndexPolicies
//     and logs:DescribeAccountPolicies permissions.
func (c *Client) DescribeAccountPolicies(ctx context.Context, params *DescribeAccountPoliciesInput, optFns ...func(*Options)) (*DescribeAccountPoliciesOutput, error) {
	if params == nil {
		params = &DescribeAccountPoliciesInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeAccountPolicies", params, optFns, c.addOperationDescribeAccountPoliciesMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeAccountPoliciesOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeAccountPoliciesInput struct {

	// Use this parameter to limit the returned policies to only the policies that
	// match the policy type that you specify.
	//
	// This member is required.
	PolicyType types.PolicyType

	// If you are using an account that is set up as a monitoring account for
	// CloudWatch unified cross-account observability, you can use this to specify the
	// account ID of a source account. If you do, the operation returns the account
	// policy for the specified account. Currently, you can specify only one account ID
	// in this parameter.
	//
	// If you omit this parameter, only the policy in the current account is returned.
	AccountIdentifiers []string

	// The token for the next set of items to return. (You received this token from a
	// previous call.)
	NextToken *string

	// Use this parameter to limit the returned policies to only the policy with the
	// name that you specify.
	PolicyName *string

	noSmithyDocumentSerde
}

type DescribeAccountPoliciesOutput struct {

	// An array of structures that contain information about the CloudWatch Logs
	// account policies that match the specified filters.
	AccountPolicies []types.AccountPolicy

	// The token to use when requesting the next set of items. The token expires after
	// 24 hours.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeAccountPoliciesMiddlewares(stack *middleware.Stack, options Options) (err error) {
	if err := stack.Serialize.Add(&setOperationInputMiddleware{}, middleware.After); err != nil {
		return err
	}
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpDescribeAccountPolicies{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpDescribeAccountPolicies{}, middleware.After)
	if err != nil {
		return err
	}
	if err := addProtocolFinalizerMiddlewares(stack, options, "DescribeAccountPolicies"); err != nil {
		return fmt.Errorf("add protocol finalizers: %v", err)
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addSetLoggerMiddleware(stack, options); err != nil {
		return err
	}
	if err = addClientRequestID(stack); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRetry(stack, options); err != nil {
		return err
	}
	if err = addRawResponseToMetadata(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = addSpanRetryLoop(stack, options); err != nil {
		return err
	}
	if err = addClientUserAgent(stack, options); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addSetLegacyContextSigningOptionsMiddleware(stack); err != nil {
		return err
	}
	if err = addTimeOffsetBuild(stack, c); err != nil {
		return err
	}
	if err = addUserAgentRetryMode(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDescribeAccountPoliciesValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware_opDescribeAccountPolicies(options.Region), middleware.Before); err != nil {
		return err
	}
	if err = addRecursionDetection(stack); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addSpanInitializeStart(stack); err != nil {
		return err
	}
	if err = addSpanInitializeEnd(stack); err != nil {
		return err
	}
	if err = addSpanBuildRequestStart(stack); err != nil {
		return err
	}
	if err = addSpanBuildRequestEnd(stack); err != nil {
		return err
	}
	return nil
}

func newServiceMetadataMiddleware_opDescribeAccountPolicies(region string) *awsmiddleware.RegisterServiceMetadata {
	return &awsmiddleware.RegisterServiceMetadata{
		Region:        region,
		ServiceID:     ServiceID,
		OperationName: "DescribeAccountPolicies",
	}
}
